==> roccat-tools-1.0.0.tar.bz2: roccat-tools-1.0.0/ryos/ryosconfig/ryosconfig_update_assistant.h <==
#ifndef __RYOSCONFIG_UPDATE_ASSISTANT_H__
#define __RYOSCONFIG_UPDATE_ASSISTANT_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_update_assistant.h"

G_BEGIN_DECLS

#define RYOSCONFIG_UPDATE_ASSISTANT_TYPE (ryosconfig_update_assistant_get_type())
#define RYOSCONFIG_UPDATE_ASSISTANT(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), RYOSCONFIG_UPDATE_ASSISTANT_TYPE, RyosconfigUpdateAssistant))
#define IS_RYOSCONFIG_UPDATE_ASSISTANT(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), RYOSCONFIG_UPDATE_ASSISTANT_TYPE))
#define RYOSCONFIG_UPDATE_ASSISTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), RYOSCONFIG_UPDATE_ASSISTANT_TYPE, RyosconfigUpdateAssistantClass))
#define IS_RYOSCONFIG_UPDATE_ASSISTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), RYOSCONFIG_UPDATE_ASSISTANT_TYPE))

typedef struct _RyosconfigUpdateAssistant RyosconfigUpdateAssistant;
typedef struct _RyosconfigUpdateAssistantClass RyosconfigUpdateAssistantClass;
typedef struct _RyosconfigUpdateAssistantPrivate RyosconfigUpdateAssistantPrivate;

struct _RyosconfigUpdateAssistant {
	RoccatUpdateAssistant parent;
	RyosconfigUpdateAssistantPrivate *priv;
};

struct _RyosconfigUpdateAssistantClass {
	RoccatUpdateAssistantClass parent_class;
};

GType ryosconfig_update_assistant_get_type(void);
GtkWidget *ryosconfig_update_assistant_new(GtkWindow *parent, RoccatDevice **ryos);

void ryosconfig_update_assistant(GtkWindow *parent, RoccatDevice **ryos);

G_END_DECLS

#endif

==> roccat-tools-1.6.0.tar.bz2: roccat-tools-1.6.0/ryos/ryosconfig/ryosconfig_update_assistant.h <==
#ifndef __RYOSCONFIG_UPDATE_ASSISTANT_H__
#define __RYOSCONFIG_UPDATE_ASSISTANT_H__

/*
 * This file is part of roccat-tools.
 *
 * roccat-tools is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * roccat-tools is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with roccat-tools. If not, see <http://www.gnu.org/licenses/>.
 */

#include "roccat_update_assistant.h"

G_BEGIN_DECLS

#define RYOSCONFIG_UPDATE_ASSISTANT_TYPE (ryosconfig_update_assistant_get_type())
#define RYOSCONFIG_UPDATE_ASSISTANT(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), RYOSCONFIG_UPDATE_ASSISTANT_TYPE, RyosconfigUpdateAssistant))
#define IS_RYOSCONFIG_UPDATE_ASSISTANT(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), RYOSCONFIG_UPDATE_ASSISTANT_TYPE))
#define RYOSCONFIG_UPDATE_ASSISTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST((klass), RYOSCONFIG_UPDATE_ASSISTANT_TYPE, RyosconfigUpdateAssistantClass))
#define IS_RYOSCONFIG_UPDATE_ASSISTANT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE((klass), RYOSCONFIG_UPDATE_ASSISTANT_TYPE))

typedef struct _RyosconfigUpdateAssistant RyosconfigUpdateAssistant;
typedef struct _RyosconfigUpdateAssistantClass RyosconfigUpdateAssistantClass;
typedef struct _RyosconfigUpdateAssistantPrivate RyosconfigUpdateAssistantPrivate;

struct _RyosconfigUpdateAssistant {
	RoccatUpdateAssistant parent;
	RyosconfigUpdateAssistantPrivate *priv;
};

struct _RyosconfigUpdateAssistantClass {
	RoccatUpdateAssistantClass parent_class;
};

GType ryosconfig_update_assistant_get_type(void);
GtkWidget *ryosconfig_update_assistant_new(GtkWindow *parent, RoccatDevice *ryos);

void ryosconfig_update_assistant(GtkWindow *parent, RoccatDevice *ryos);

G_END_DECLS

#endif
